Error

Enum Error 

#[non_exhaustive]
pub enum Error { InvalidConfig { field: &'static str, reason: &'static str, }, DeviceNotFound, DeviceClosed, Busy, Unsupported, StreamClosed { reason: &'static str, }, Usb(Error), Transfer(TransferError), Operation { operation: &'static str, source: Box<Error>, }, Protocol { operation: &'static str, reason: &'static str, }, }
Error returned by a HackRF operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidConfig

A transceiver configuration value failed validation.

Fields

field: &'static str

Name of the invalid field.

reason: &'static str

Reason the value is invalid.



DeviceNotFound

No matching HackRF device was found.



DeviceClosed

The logical device session has been shut down.



Busy

The device or USB resource is already in use.



Unsupported

The requested operation is unsupported.



StreamClosed

A stream is stopped or unusable.

Fields

reason: &'static str

Reason the stream is unavailable.



Usb(Error)

The USB backend returned an error outside an individual transfer.



Transfer(TransferError)

An individual USB transfer failed.



Operation

A driver operation failed with a more specific source error.

Fields

operation: &'static str

Operation being performed.

source: Box<Error>

Underlying error.



Protocol

The device violated the expected HackRF USB protocol.

Fields

operation: &'static str

Operation that failed.

reason: &'static str

Unexpected response or state.

Implementations

Source

impl Error

pub fn kind(&self) -> ErrorKind

Return a backend-independent error category.