#[non_exhaustive]pub enum Error {
InvalidConfig {
field: &'static str,
reason: &'static str,
},
DeviceNotFound,
DeviceClosed,
Busy,
Unsupported,
StreamClosed {
reason: &'static str,
},
Usb(Error),
Transfer(TransferError),
Operation {
operation: &'static str,
source: Box<Error>,
},
Protocol {
operation: &'static str,
reason: &'static str,
},
}Expand description
Error returned by a HackRF operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidConfig
A transceiver configuration value failed validation.
Fields
DeviceNotFound
No matching HackRF device was found.
DeviceClosed
The logical device session has been shut down.
Busy
The device or USB resource is already in use.
Unsupported
The requested operation is unsupported.
StreamClosed
A stream is stopped or unusable.
Usb(Error)
The USB backend returned an error outside an individual transfer.
Transfer(TransferError)
An individual USB transfer failed.
Operation
A driver operation failed with a more specific source error.
Protocol
The device violated the expected HackRF USB protocol.
Implementations